#
# spec file for package python-envisage
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         skip_python2 1
%define         X_display         ":98"
%bcond_without     test
Name:           python-envisage
Version:        6.1.1
Release:        1.6
Summary:        Extensible application framework for Python
# Source code is under BSD but images are under different licenses
# and details are inside image_LICENSE.txt
License:        BSD-3-Clause AND Python-2.0 AND LGPL-3.0-only AND CC-BY-SA-1.0 AND CC-BY-SA-2.0 AND CC-BY-SA-2.5 AND CC-BY-SA-3.0 AND SUSE-Public-Domain
URL:            https://github.com/enthought/envisage
Source:         https://files.pythonhosted.org/packages/source/e/envisage/envisage-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module traits >= 6.2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-traits >= 6.2
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module apptools}
# Only test optional ipykernel where we still have an old version -- gh#enthought/envisage#423
BuildRequires:  %{python_module ipykernel < 6 if %python-base < 3.7}
BuildRequires:  %{python_module traitsui}
BuildRequires:  xorg-x11-server
%endif
%python_subpackages

%description
Envisage is a Python-based framework for building extensible
applications, that is, applications whose functionality can be
extended by adding "plug-ins". Envisage provides a standard mechanism
for features to be added to an application. When building an
application using Envisage, the entire application consists primarily
of plug-ins. In this respect, it is similar to the Eclipse and
Netbeans frameworks for Java applications.

Part of the Enthought Tool Suite (ETS).

%prep
%setup -q -n envisage-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10

%pyunittest -v
%endif

%files %{python_files}
%doc README.rst
%license LICENSE.txt image_LICENSE.txt image_LICENSE_CP.txt
%{python_sitelib}/envisage/
%{python_sitelib}/envisage-%{version}-py*.egg-info

%changelog
* Thu Mar  2 2023 Daniel Garcia <daniel.garcia@suse.com>
- Remove py310-eggs.tar.gz source, it's upstreamed now.
- Update to 6.1.1
  * A trait validation error in the Workbench DefaultActionSet has
    been fixed. This fixes a compatibility issue with Traits 6.4.
    (#485)
  * Initialization of application directories now correctly respects
    the value of self.state_location. (#490)
  * In the test suite, egg generation now uses sys.executable to
    ensure it picks up the correct Python executable. (#499)
  * The version of PySide6 used in test workflows has been restricted.
    (#487)
  * The EDM version used in test workflow has been updated. (#484)
  * Various fixes have been made to the GitHub Actions workflows, for
    compatibility with the newest runners. (#491, #494)
  * Copyright headers have been updated for 2023. (#493)
- 6.1.0
  * The Application.user_data directory no longer includes the id
  * of the application, but instead matches the ETSConfig.user_data. (#467)
  * The Envisage Application will no longer try to change the
  * ETSConfig.application_home attribute. (#467)
  * The PackageResourceProtocol now uses importlib.resources instead
  * of pkg_resources. (#466)
  * The IPython-related features of Envisage require ipykernel version < 6 and
  * IPython version < 8. (#449)
  * Fix EggPluginManager to use current pkg_resources.working_set. (#444)
  * Simplify ImportManager by using importlib. (#465)
  * Update end year in copyright headers. (#458)
* Tue Jan 25 2022 Dirk Müller <dmueller@suse.com>
- add test eggs for python 3.10 build
* Mon Aug 30 2021 Ben Greiner <code@bnavigator.de>
- Update to 6.0.1
  * This bugfix release fixes the issue where Extension
    Point resolution was happening too eagerly, which caused
    issues during application startup time in certain cases. We
    recommend all users of Envisage to upgrade to this bugfix
    version.
- Release 6.0.0
  * This major release focuses on speeding up Envisage
    applications. We achieved this speedup by removing
    unused functionality in the package. Specifically, we
    removed the @contributes_to decorator and the code
    needed to handle methods decorated with the above
    decorator.
  * Additionally, with this release, parts of Envisage
    start using the new Traits observation framework instead
    of the old Traits on_trait_change. So, Envisage now
    depends on Traits version >= 6.2.
- Don't test with ipykernel => 6 -- gh#enthought/envisage#448
* Mon May  3 2021 Markéta Machová <mmachova@suse.com>
- Update to 5.0.0
  * Create and fill plugin subpackage api modules
  * Deprecate safeweakref and replace its uses
  * Drop support for Python 3 versions older than Python 3.6.
  * Remove single_project
  * Remove class_load_hooks and ClassLoadHook
- Remove nose, tests can be run by unittest now
* Thu Jul  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 4.9.2
  - Conditionally skip tests that fail against Traits 6.0.0 due to the removal
    of Categories. (#263)
  - Fix tests that fail against Traits 6.0.0 due to the removal
    of double nesting in list events. (#255)
  - Replace a comment mention of ``AdaptedTo`` with ``Supports``. (#253)
  - Remove dependence on ``clean_filename`` from Traits. (#252)
  - Replace a use of the deprecated ``DictStrAny`` trait with
    ``Dict(Str, Any)``. (#250)
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to Version 4.9.0
  + Features
  * Add an option to allow the ``InternalIPKernel`` to initialise its kernel at
    kernel creation time. At some point in the future, this will become the
    default behaviour.
  + Fixes
  * Replace a use of the deprecated ``adapts`` function with
    ``register_factory``.
  * In the ``IPKernelApp``, correctly restore the original state of
    ``IPython.utils.io.std*`` streams even if those streams didn't exist
    originally.
  * Remove duplicate copyright header from autogenerated version file.
  + Tests
  * Remove a ``print`` call from a unit test.
  * Add unit tests for the ``envisage.ui.single_project`` adapters.
  * Add unit tests to check that ``InternalIPKernel`` doesn't affect
    ``sys.path``.
  * Fix the test suite not to write to the user's ``~/.ipython`` directory.
  * Fix the test suite not to write to the user's ``~/.enthought`` directory.
  * Remove an unused import and a useless ``tearDown`` method in the
    ``IPythonKernel`` tests.
  * Fix ``DeprecationWarning``s from uses of long-deprecated ``TestCase``
    methods.
  * Add test eggs for Python 3.8.
  + Build
  * Rename changelog extension from ``.txt`` to ``.rst``.
  * Update EDM version used in Travis CI and Appveyor.
  * Add ``mock`` to test dependencies on Python 2.
  * Fix status badges in ``README``.
- Update to Version 4.8.0
  + Features
  * Improved ``repr`` for ``ExtensionPoint`` objects.
  + Changes
  * Drop support for Python versions older than 2.7 and Python 3 versions older
    than Python 3.5.
  * The ``IPythonKernelPlugin`` now releases all allocated resources (threads,
    file descriptors, etc.) and undoes global state changes at plugin ``stop``
    time.
  * Suppress the Ctrl-C message printed by the IPython kernel at start time.
  * Add license headers to all files, and make license header statements
    consistent.
  + Fixes
  * Use a fixed pickle protocol when saving task layout state, to avoid
    cross-Python-version difficulties.
  * Fix deprecation warnings from use of ``Logger.warn``.
  * Fix some Python 3 syntax errors in example scripts.
  + Removals
  * Remove the unsupported and incomplete ``UpdateCheckerPlugin``.
  * Remove the ``plugin.debug`` empty submodule.
  * Remove the old ``IPythonShell`` plugin, which was based on pre-IPython 1.0.
  * Remove the non-functional ``RefreshCodePlugin``.
  * Remove ``project_runnable``, which was never functional.
  * Remove outdated debugging fallback from the ``ExtensionPoint`` source.
  * Remove ``FBIPlugin``.
  * Remove the ``remote_editor`` plugins.
  + Documentation
  * Add docstrings for tasks plugin extension points.
  * Fix incorrect documentation for ``always_use_default_layout``.
  * Spell "Pyface" correctly.
  * NumPyDoc style fixes.
  * Add API documentation, with corresponding build infrastructure.
  * Fix invalid syntax in Tetris example.
  * Use the Enthought Sphinx Theme for documentation.
  + Tests
  * Remove dependency on the ``nose`` package, and rename test modules. All
    tests can now be discovered and run using ``unittest``.
  + Build
  * Revise version-handling mechanisms and other minor details
    in ``setup.py`` script.
  * Remove unused and outdated ``tox.ini`` file.
  * Update ``etstool.py`` to work with a non-EDM bootstrap environment on
    Windows.
  * Test against other ETS packages from source, using Travis CI cron jobs.
  * Fix deprecated pieces in Travis CI configuration.
  * Update EDM version used, and clean up and simplify Travis CI and
    Appveyor configurations.
  * Usability improvements to ``etstool.py``.
* Tue May 14 2019 Gary Smith <GSmith@suse.com>
- Update to version 4.7.2
  * no changelog
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to version 4.7.0
  * Add failing test and fix for old-style relative import. (#109)
  * Old-style relative import ipython_kernel plugin (#108)
  * Fix attractors example (#103)
  * Use --gui rather than --matplotlib when starting IPython kernel. (#101)
  * InternalIPKernel.shutdown method doesn't stop the kernel's IOPubThread (#93)
  * Fix task layout serialization under Python3
* Fri May 18 2018 jengelh@inai.de
- Do not assume any specific user in the description.
* Wed May  9 2018 toddrme2178@gmail.com
- Add license files
* Wed Aug 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 4.6.0
  * no changelog
* Tue Apr 12 2016 toddrme2178@gmail.com
- Update to Version 4.5.1
  + Enhancements
  * Add tox for testing package install (#67)
  + Fixes
  * Include missing test files in the package data (#67)
  * Include missing test cases for Python 3.4 (#67)
- Update to Version 4.5.0
  + New features
  * IPythonKernelPlugin for Tasks: run an IPython kernel within the
    envisage app and expose it as a service (#54).
  * Envisage now supports Python 3.4 (#61).
  + Enhancements
  * Allow loading plugins from an egg basket even when some eggs are
    invalid (#40, #46).
  * Add a simple ``GUIApplication`` to bootstrap basic plugin-driven
    applications (#34).
  * Split the IPython kernel and IPython menu action into two separate
    plugins for flexibility (#57).
  + Fixes
  * Use new Traits interfaces and adaptation implementation (#37).
  * Envisage now configures the logger with a ``NullHandler`` to avoid
    spurios unconfigured logger warnings (#45).
  * Envisage no longer swallows exceptions in plugin startup (#50).
  * Various fixes to continuous integration configuration (#47, #60).
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 4.4.0
  * no changelog
- Update source to pypi url.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 4.3.0
  * no changelog
* Tue May 22 2012 toddrme2178@gmail.com
- Initial spec file
